;; Generated package description from spacious-padding.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "spacious-padding" "0.8.0.0.20260111.105014" "Increase the padding/spacing of frames and windows" '((emacs "28.1")) :commit "a9cddfb2e2d212d7723104fb049e34f30240f063" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :keywords '("convenience" "focus" "writing" "presentation") :url "https://github.com/protesilaos/spacious-padding")
